@@ -1,22 +1,8 @@
-/****************************************************************************
-Copyright 2018  Marco Martin <notmart@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2018 Marco Martin <notmart@gmail.com>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-****************************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "plasmavirtualdesktop_interface.h"
 #include "display.h"
 #include "global_p.h"
@@ -56,7 +42,6 @@ private:
         return reinterpret_cast<Private*>(wl_resource_get_user_data(resource));
     }
 
-    wl_listener listener;
     static const struct org_kde_plasma_virtual_desktop_interface s_interface;
 };
 
@@ -232,7 +217,7 @@ PlasmaVirtualDesktopInterface *PlasmaVirtualDesktopManagementInterface::createDe
     }
 
     const quint32 actualPosition = qMin(position, (quint32)d->desktops.count());
- 
+
     PlasmaVirtualDesktopInterface *desktop = new PlasmaVirtualDesktopInterface(this);
     desktop->d->id = id;
     for (auto it = desktop->d->resources.constBegin(); it != desktop->d->resources.constEnd(); ++it) {
