@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SERVER_SEAT_INTERFACE_P_H
 #define WAYLAND_SERVER_SEAT_INTERFACE_P_H
 // KWayland
@@ -24,6 +10,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "global_p.h"
 // Qt
 #include <QHash>
+#include <QMap>
 #include <QPointer>
 #include <QVector>
 // Wayland
@@ -46,7 +33,7 @@ public:
     void sendName(wl_resource *r);
     QVector<PointerInterface *> pointersForSurface(SurfaceInterface *surface) const;
     QVector<KeyboardInterface *> keyboardsForSurface(SurfaceInterface *surface) const;
-    TouchInterface *touchForSurface(SurfaceInterface *surface) const;
+    QVector<TouchInterface *> touchsForSurface(SurfaceInterface *surface) const;
     DataDeviceInterface *dataDeviceForSurface(SurfaceInterface *surface) const;
     TextInputInterface *textInputForSurface(SurfaceInterface *surface) const;
     void registerDataDevice(DataDeviceInterface *dataDevice);
@@ -99,9 +86,8 @@ public:
         };
         QHash<quint32, State> states;
         struct Keymap {
-            int fd = -1;
-            quint32 size = 0;
             bool xkbcommonCompatible = false;
+            QByteArray content;
         };
         Keymap keymap;
         struct Modifiers {
@@ -140,17 +126,19 @@ public:
     };
     TextInput textInput;
 
+    // Touch related members
     struct Touch {
         struct Focus {
             SurfaceInterface *surface = nullptr;
-            TouchInterface *touch = nullptr;
+            QVector<TouchInterface*> touchs;
             QMetaObject::Connection destroyConnection;
             QPointF offset = QPointF();
+            QPointF firstTouchPos;
         };
         Focus focus;
-        QVector<qint32> ids;
+        QMap<qint32, quint32> ids;
     };
-    Touch touchInterface;
+    Touch globalTouch;
 
     struct Drag {
         enum class Mode {
@@ -163,6 +151,7 @@ public:
         DataDeviceInterface *target = nullptr;
         SurfaceInterface *surface = nullptr;
         PointerInterface *sourcePointer = nullptr;
+        TouchInterface *sourceTouch = nullptr;
         QMatrix4x4 transformation;
         QMetaObject::Connection destroyConnection;
         QMetaObject::Connection dragSourceDestroyConnection;
@@ -186,6 +175,7 @@ private:
     static void getPointerCallback(wl_client *client, wl_resource *resource, uint32_t id);
     static void getKeyboardCallback(wl_client *client, wl_resource *resource, uint32_t id);
     static void getTouchCallback(wl_client *client, wl_resource *resource, uint32_t id);
+    static void releaseCallback(wl_client *client, wl_resource *resource);
     static const struct wl_seat_interface s_interface;
     static const quint32 s_version;
     static const qint32 s_pointerVersion;
